=======
Credits
=======

Development Lead
----------------
* Anderson Banihirwe <abanihi@ucar.edu> `@andersy005 <https://github.com/andersy005>`_
* David Huard <david.huard@gmail.com> `@huard <https://github.com/huard>`_

Maintainers
-----------
* Abel Aoun <aoun.abel@gmail.com> `@bzah <https://github.com/bzah>`_
* Trevor James Smith <trevor_smith@live.com> `@Zeitsperre <https://github.com/Zeitsperre>`_

Contributors
-------------
* Pascal Bourgault <bourgault.pascal@ouranos.ca> `@aulemhahal <https://github.com/aulemahal>`_
* Francis Charette-Migneault <francis.charette.migneault@gmail.com> `@fmigneault <https://github.com/fmigneault>`_
